pub enum OutputMode {
Silent,
Standard,
}Expand description
Controls the level of output produced by lingora-cli.
Variants
Silent
Enables lingora to complete the error checks on the reference and target files, returning an error status if found. No detailed report will be produced.
Standard
Output analysis report details to stdout.